@@ -31,7 +31,7 @@ use File::Basename 'basename';
 use base 'Exporter';
 
 $AUTHORITY = 'SUKRIA';
-$VERSION   = '1.3000_01';
+$VERSION   = '1.3000_02';
 @EXPORT    = qw(
   after
   any
@@ -45,7 +45,9 @@ $VERSION   = '1.3000_01';
   del
   dirname
   error
+  engine
   false
+  forward
   from_dumper
   from_json
   from_yaml
@@ -107,9 +109,11 @@ sub content_type    { Dancer::Response->content_type(@_) }
 sub dance           { Dancer::start(@_) }
 sub debug           { goto &Dancer::Logger::debug }
 sub dirname         { Dancer::FileUtils::dirname(@_) }
+sub engine          { Dancer::Engine->engine(@_) }
 sub error           { goto &Dancer::Logger::error }
 sub send_error      { Dancer::Helpers->error(@_) }
 sub false           {0}
+sub forward         { Dancer::Response->forward(shift) }
 sub from_dumper     { Dancer::Serializer::Dumper::from_dumper(@_) }
 sub from_json       { Dancer::Serializer::JSON::from_json(@_) }
 sub from_yaml       { Dancer::Serializer::YAML::from_yaml(@_) }
@@ -445,6 +449,14 @@ Returns the dirname of the path given:
 
     my $dir = dirname($some_path);
 
+=head2 engine
+
+Given an namespace, returns the current engine object
+
+    my $template_engine = engine 'template';
+    my $html = $template_engine->apply_renderer(...);
+    $template_engine->apply_layout($html);
+
 =head2 error
 
 Logs a message of error level:
@@ -455,6 +467,35 @@ Logs a message of error level:
 
 Constant that returns a false value (0).
 
+=head2 forward
+
+Runs an internal redirect of the current request to another request. This helps
+you avoid having to redirect the user using HTTP and set another request to your
+application.
+
+It effectively lets you chain routes together in a clean manner.
+
+    get qr{ /demo/articles/(.+) }x => sub {
+        my ($article_id) = splat;
+
+        # you'll have to implement this next sub yourself :)
+        change_the_main_database_to_demo();
+
+        forward '/articles/$article_id';
+    };
+
+In the above example, the users that reach I</demo/articles/30> will actually
+reach I</articles/30> but we've changed the database to demo before.
+
+This is pretty cool because it lets us retain our paths and offer a demo
+database by merely going to I</demo/...>.
+
+You'll notice that in the example we didn't indicate whether it was B<GET> or
+B<POST>. That is because C<forward> chains the same type of route the user
+reached. If it was a B<GET>, it will remain a B<GET>.
+
+Broader functionality might be added in the future.
+
 =head2 from_dumper ($structure)
 
 Deserializes a Data::Dumper structure.
@@ -682,13 +723,19 @@ function, e.g.
 Allows a handler to provide plain HTML (or other content), but have it rendered
 within the layout still.
 
-For example:
+This method is B<DEPRECATED>, and will be removed soon. Instead, you should be
+using the C<engine> keyword:
 
     get '/foo' => sub {
         # Do something which generates HTML directly (maybe using
         # HTML::Table::FromDatabase or something)
         my $content = ...;
-        render_with_layout $content;
+
+        # get the template engine
+        my $template_engine = engine 'template';
+
+        # apply the layout (not the renderer), and return the result
+        $template_engine->apply_layout($content)
     };
 
 It works very similarly to C<template> in that you can pass tokens to be used in
