@@ -21,6 +21,7 @@ sub new {
         headers => $headers,
         content => "",
         pass    => 0,
+        forward => "",
         %args,
     };
     bless $self, $class;
@@ -101,6 +102,16 @@ sub pass {
     $current->{pass} = 1
 }
 
+sub forward {
+    my $current = _get_object(shift);
+    $current->{forward} = $_[0];
+}
+
+sub is_forwarded { 
+    my $current = _get_object(shift);
+    $current->{forward};
+}
+
 sub has_passed {
     my $current = _get_object(shift);
     $current->{pass};
